@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 from .nodes import (
     filter_operator,
+    GlobalNode,
     InputNode,
     MergeOutputsNode,
     OutputNode,
@@ -25,10 +26,11 @@ def input(filename, **kwargs):
 
 @output_operator()
 def overwrite_output(stream):
-    """No longer supported; see ``overwrite_output`` parameter of ``get_args`` function instead.
+    """Overwrite output files without asking (ffmpeg ``-y`` option)
+
+    Official documentation: `Main options <https://ffmpeg.org/ffmpeg.html#Main-options>`__
     """
-    raise NameError('`overwrite_output` operator is no longer supported; see `overwrite_output` parameter of '
-        '`get_args` function instead')
+    return GlobalNode(stream, overwrite_output.__name__).stream()
 
 
 @output_operator()
